@@ -3,7 +3,7 @@ from .metadata_getter import MetadataGetter, MetadataValidator
 
 class RequisitionMetadataValidator(MetadataValidator):
     @property
-    def extra_query_attrs(self):
+    def extra_query_attrs(self) -> dict:
         return dict(panel__name=self.metadata_obj.panel_name)
 
 
