@@ -1,3 +1,5 @@
+from typing import Any, Optional
+
 from ...constants import CRF
 from ..rule import Rule
 
@@ -7,12 +9,12 @@ class CrfRuleModelConflict(Exception):
 
 
 class CrfRule(Rule):
-    def __init__(self, target_models=None, **kwargs):
+    def __init__(self, target_models: Optional[Any] = None, **kwargs) -> None:
         super().__init__(**kwargs)
         self.metadata_category = CRF
         self.target_models = target_models
 
-    def run(self, visit=None):
+    def run(self, visit: Optional[Any] = None) -> Any:
         if self.source_model in self.target_models:
             raise CrfRuleModelConflict(
                 f"Source model cannot be a target model. Got '{self.source_model}' "
